@@ -34,7 +34,7 @@ public class PostgresqlIdentityValueLoader2 implements IdentityValueLoader {
 	 * @return The newly inserted id.
 	 */
 	public long getLastInsertId() {
-		return dbCtx.getJdbcTemplate().queryForLong(SQL_SELECT_LAST_INSERT_ID);
+		return dbCtx.getJdbcTemplate().queryForObject(SQL_SELECT_LAST_INSERT_ID, Long.class);
 	}
 
 
@@ -43,7 +43,7 @@ public class PostgresqlIdentityValueLoader2 implements IdentityValueLoader {
 	 */
 	@Override
 	public long getLastSequenceId(String sequenceName) {
-		return dbCtx.getJdbcTemplate().queryForLong(SQL_SELECT_LAST_SEQUENCE_ID, sequenceName);
+		return dbCtx.getJdbcTemplate().queryForObject(SQL_SELECT_LAST_SEQUENCE_ID, Long.class, sequenceName);
 	}
 	
 	
